# Convert

```sh
automesh convert --help
<!-- cmdrun automesh convert --help -->
```

## Convert Mesh

```sh
automesh convert mesh --help
<!-- cmdrun automesh convert mesh --help -->
```

## Convert Segmentation

```sh
automesh convert segmentation --help
<!-- cmdrun automesh convert segmentation --help -->
```
